@@ -5,15 +5,6 @@ import importlib
 import sys
 
 
-CONFIG = {
-    "version": {
-        "default": False,
-        "action": "store_true",
-        "help": "Display version information",
-    }
-}
-
-
 def run(hub, primary):
     """
     Check the version number and then exit
