@@ -22,7 +22,8 @@ def setup(hub, conf):
     root.addHandler(ch)
 
     ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
-    fh = logging.FileHandler(conf["log_file"])
+    _, kwargs = hub.render.cli.args(conf["log_handler_options"])
+    fh = logging.FileHandler(filename=conf["log_file"], delay=True, **kwargs)
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
